# Tax-Brain Road Map

## Near-Term

* Update Tax-Brain to allow users to take full advantage of the `GrowDiff` capabilities of Tax-Calculator.
* Integration of the [OG-USA](http://pslmodels.github.io/OG-USA/content/intro/intro.html) model to be used to update the underlying macroeconomic forecasts used to extrapolate the microdata used by Tax-Calculator.
## Long-Term

The next models to be incorporated into Tax-Brain will be (in no particular order):

* [Cost-of-Capital-Calculator](https://ccc.pslmodels.org)
* [Business-Taxation](https://github.com/PSLmodels/Business-Taxation)

## Completed

The first goal of the Tax-Brain project was to wrap the [Tax-Calculator](https://taxcalc.pslmodels.org)
and [Behavioral-Responses](https://www.pslmodels.org/Catalog/Behavioral-Responses.html)
packages.

Second, we developed a GUI web application on the Compute Studio platform, available at [https://compute.studio/PSLmodels/Tax-Brain/](https://compute.studio/PSLmodels/Tax-Brain/).